@@ -8,8 +8,8 @@ class Payout:
         self.app = app
         self.key = key
         # Get app endpoints
-        conn = http.client.HTTPSConnection("https://dashboard.redshepherd.com")
-        route = "app/endpoints/" + self.app
+        conn = http.client.HTTPSConnection("dashboard.redshepherd.com")
+        route = "/app/endpoints/" + self.app
         # Send the request
         conn.request('POST', route)
         response = json.loads(conn.getresponse().read().decode())
